==> oto-service-api-0.2.49-20250425.020333-2-sources.jar: cn/com/duiba/oto/oto/service/api/remoteservice/pet/RemotePetOrderService.java <==
package cn.com.duiba.oto.oto.service.api.remoteservice.pet;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderCalculateResultDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderCreateResultDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderDetailDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderListItemDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderStatusStatisticsDto;
import cn.com.duiba.oto.dto.oto.pet.RemotePetOrderListItemDto;
import cn.com.duiba.oto.param.oto.pet.RemoteMatchPetDoctorParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderCalculateParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderCreateParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderDetailQueryParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderListQueryParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderRefundParam;
import cn.com.duiba.oto.param.oto.pet.RemotePetOrderCompleteParam;
import cn.com.duiba.oto.param.oto.pet.RemotePetOrderSearchParam;
import cn.com.duiba.oto.util.PageResult;

import java.util.List;

/**
 * 宠物订单相关
 *
 * @author xiaotian
 * @date 2025/4/14 2:15 PM
 *
 **/
@AdvancedFeignClient
public interface RemotePetOrderService {

    // 1. 我的订单列表（分页+状态筛选）
    PageResult<RemoteOrderListItemDto> getOrderList(RemoteOrderListQueryParam param);

    // 2. 订单详情
    RemoteOrderDetailDto getOrderDetail(RemoteOrderDetailQueryParam param);

    //获取订单状态
    Integer getOrderStatus(Long orderId);

    // 3. 计算订单金额（主+子订单）
    RemoteOrderCalculateResultDto calculateOrderAmount(RemoteOrderCalculateParam param) throws BizException;

    // 4. 新增预约单
    RemoteOrderCreateResultDto createOrder(RemoteOrderCreateParam param) throws BizException;

    /**
     * 申请退款
     */
    Boolean applyRefund(RemoteOrderDetailQueryParam param) throws BizException;

    /**
     * 5. 预约单统计
     *
     * @return
     */
    List<RemoteOrderStatusStatisticsDto> getOrderStatistics(Long userId);

    /**----------------------------------------------------crm--------------------------------------------------------**/

    /**
     * 订单列表搜索（分页）
     */
    PageResult<RemotePetOrderListItemDto> searchOrders(RemotePetOrderSearchParam param);


    /**
     * 标记订单完成
     */
    Boolean markOrderComplete(RemotePetOrderCompleteParam param);

    /**
     * 审核退款
     */
    Boolean auditRefund(RemoteOrderRefundParam param) throws BizException;

    /**
     * 匹配宠托师
     */
    Boolean matchPetDoctor(RemoteMatchPetDoctorParam remoteMatchPetDoctorParam) throws BizException;

}

==> oto-service-api-0.2.71-sources.jar: cn/com/duiba/oto/oto/service/api/remoteservice/pet/RemotePetOrderService.java <==
package cn.com.duiba.oto.oto.service.api.remoteservice.pet;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderCalculateResultDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderCreateResultDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderDetailDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderListItemDto;
import cn.com.duiba.oto.dto.oto.pet.RemoteOrderStatusStatisticsDto;
import cn.com.duiba.oto.dto.oto.pet.RemotePetOrderListItemDto;
import cn.com.duiba.oto.dto.oto.pet.WashServiceItemBasePriceDto;
import cn.com.duiba.oto.dto.oto.pet.WashServiceItemPriceDto;
import cn.com.duiba.oto.dto.oto.pet.order.PetOfflineOrdersDto;
import cn.com.duiba.oto.dto.oto.pet.order.RemoteOrderCalculateResultWashDto;
import cn.com.duiba.oto.dto.oto.pet.order.RemoteOrderDetailWashDto;
import cn.com.duiba.oto.param.oto.pet.RemoteMatchPetDoctorParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderCalculateParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderCreateParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderDetailQueryParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderListQueryParam;
import cn.com.duiba.oto.param.oto.pet.RemoteOrderRefundParam;
import cn.com.duiba.oto.param.oto.pet.RemotePetOrderCompleteParam;
import cn.com.duiba.oto.param.oto.pet.RemotePetOrderSearchParam;
import cn.com.duiba.oto.param.oto.pet.order.RemoteOrderCalculateWashParam;
import cn.com.duiba.oto.param.oto.pet.order.RemoteWashOrderCreateParam;
import cn.com.duiba.oto.util.PageResult;

import java.util.List;

/**
 * 宠物订单相关
 *
 * @author xiaotian
 * @date 2025/4/14 2:15 PM
 *
 **/
@AdvancedFeignClient
public interface RemotePetOrderService {

    // 1. 我的订单列表（分页+状态筛选）
    PageResult<RemoteOrderListItemDto> getOrderList(RemoteOrderListQueryParam param);

    // 2. 订单详情
    RemoteOrderDetailDto getOrderDetail(RemoteOrderDetailQueryParam param);

    //获取订单状态
    Integer getOrderStatus(Long orderId);

    // 3. 计算订单金额（主+子订单）
    RemoteOrderCalculateResultDto calculateOrderAmount(RemoteOrderCalculateParam param) throws BizException;

    // 4. 新增预约单
    RemoteOrderCreateResultDto createOrder(RemoteOrderCreateParam param) throws BizException;

    /**
     * 申请退款
     */
    Boolean applyRefund(RemoteOrderDetailQueryParam param) throws BizException;

    /**
     * 5. 预约单统计
     *
     * @return
     */
    List<RemoteOrderStatusStatisticsDto> getOrderStatistics(Long userId);


    /**-----------------------------------------------------宠物洗护--------------------------------------------------------**/
    // 洗护订单详情
    RemoteOrderDetailWashDto getWashOrderDetail(RemoteOrderDetailQueryParam param);

    // 计算洗护订单金额（主+子订单）
    RemoteOrderCalculateResultWashDto calculateWashOrderAmount(RemoteOrderCalculateWashParam param) throws BizException;

    // 4. 新增洗护预约单
    RemoteOrderCreateResultDto createWashOrder(RemoteWashOrderCreateParam param) throws BizException;

    /**
     * 根据宠物id获取洗护服务基础价格
     * @param petId
     * @return
     */
    WashServiceItemBasePriceDto washServiceItemBasePriceByPetId(Long userId, Long petId) throws BizException;


    List<WashServiceItemPriceDto> washServiceItemPrice();

    /**----------------------------------------------------crm--------------------------------------------------------**/

    /**
     * 订单列表搜索（分页）
     */
    PageResult<RemotePetOrderListItemDto> searchOrders(RemotePetOrderSearchParam param);


    /**
     * 标记订单完成
     */
    Boolean markOrderComplete(RemotePetOrderCompleteParam param);

    /**
     * 审核退款
     */
    Boolean auditRefund(RemoteOrderRefundParam param) throws BizException;

    /**
     * 匹配宠托师
     */
    Boolean matchPetDoctor(RemoteMatchPetDoctorParam remoteMatchPetDoctorParam) throws BizException;


    /**----------------------------------------------------线下订单--------------------------------------------------------**/

    /**
     * 新增更新线下订单
     */
    Long insertUpdateOfflineOrder(PetOfflineOrdersDto petOfflineOrdersDto) throws BizException;

    /**
     * 获取线下订单
     */
    PetOfflineOrdersDto getOfflineOrder(Long id);

    /**
     * 删除线下订单
     */
    Boolean deleteOfflineOrder(Long id);

}
